// src/backend/dynamic_request.cc - Copyright 2005, 2006, University
//               of Padova, dept. of Pure and Applied
//               Mathematics
//
// This file is part of SGPEMv2.
//
// This is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// SGPEMv2 is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with SGPEMv2; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

#include "dynamic_request.hh"
#include "static_request.hh"
#include "dynamic_sub_request.hh"

#include "smartp.tcc"

#include <cassert>

using namespace sgpem;
using std::vector;

DynamicRequest::DynamicRequest(StaticRequest *core,
                               DynamicThread* owner) :
    _static_request(core), _dynamic_thread(owner),
    _state(state_ready)
{
  assert(core != NULL);
  assert(owner != NULL);
}

vector<SubRequest*>
DynamicRequest::get_subrequests()
{
  return vector<SubRequest*>(_dynamic_subrequests.begin(), _dynamic_subrequests.end());
}

DynamicThread&
DynamicRequest::get_thread()
{
  return *_dynamic_thread;
}

unsigned int
DynamicRequest::get_instant() const
{
  return _static_request->get_instant();
}

Request::state
DynamicRequest::get_current_state() const
{
  return _state;
}

void
DynamicRequest::add_subrequest(DynamicSubRequest* subreq)
{
  assert(subreq != NULL);

  _dynamic_subrequests.push_back(subreq);
}

void
DynamicRequest::remove_subrequest(SubRequest* subreq)
{
  assert(subreq != NULL);

  vector<DynamicSubRequest*>::iterator it;

  it = std::find(_dynamic_subrequests.begin(), _dynamic_subrequests.end(), subreq);

  if(it != _dynamic_subrequests.end())
  {
    _dynamic_subrequests.erase(it);
    delete *it;
  }
}

void
DynamicRequest::serialize(SerializeVisitor& translator) const
{
  // Let a drunk monkey write this code ;P
}

